#
# spec file for package python-django-money
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define skip_python36 1
Name:           python-django-money
Version:        3.5.2
Release:        1.1
Summary:        Django support for using money and currency fields
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/django-money/django-money
Source:         https://github.com/django-money/django-money/archive/%{version}.tar.gz#/django-money-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Requires:       python-py-moneyed >= 0.8.0
Requires:       python-setuptools
Recommends:     python-certifi
Suggests:       python-django-reversion
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module django-reversion}
BuildRequires:  %{python_module py-moneyed >= 0.8.0}
BuildRequires:  %{python_module pytest >= 3.1.0}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module setuptools}
# /SECTION
%python_subpackages

%description
Django money and currency fields in models and forms.

%prep
%autosetup -p1 -n django-money-%{version}

sed -i -e '/^addopts/d' pytest.ini

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
PYTHONPATH=.
export DJANGO_SETTINGS_MODULE=tests.settings
export PYTHONPATH=$(pwd -P)
# we don't have python-mixer and it is needed only for tests
# test_currency_field_null_switch_not_triggered_from_default_currency is
# expected to fail according to gh#django-money/django-money#638
%pytest -k "not (mixer or test_no_deprecation_warning or test_currency_field_null_switch_not_triggered_from_default_currency)"

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/djmoney
%{python_sitelib}/django_money-%{version}*-info

%changelog
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 3.5.2:
  * django-rest-framework: Fix regression from 3.5
  * If you generated MoneyField migrations in the previous series
    3.4.x, you may have to manually edit subsequent migrations.
  * Revert 3.4 patch, meaning that auto-generated CurrencyField
    is once again part of migrations
  * django-rest-framework: MinMoneyValidator and
    MaxMoneyValidator fixed, may require default_currency defined
  * Django 5.0 support
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 3.4.1:
  * The default setting for ``CURRENCY_CHOICES`` excluded the
    currency choice defined by ``DEFAULT_CURRENCY``.
  * Don't register Django Money serializers by default, instead
    the user should actively register a serializer in the
    ``settings.py``
  * Fix detection of necessary migrations. Note that this means
    that previously undetected migrations will be detected as of
    this version
* Mon Mar 13 2023 Matej Cepl <mcepl@suse.com>
- Update to 3.0:
  - Changed
  - Update py-moneyed to 2.0.
  - Remove the deprecated Money.decimal_places_display property
    and argument.
  - Remove the deprecated CURRENCY_DECIMAL_PLACES_DISPLAY
    setting.
  - Null constraint on an implicit CurrencyField is now
    declared from null=... argument to MoneyField.
  - Fixed
  - Improve the internal check for whether a currency is
    provided
  - Fix test suite for django main branch
  - MoneyField raises TypeError when default contains a valid
    amount but no currence, i.e. Money(123, None).
  - MoneyField supports default of type bytes
  - Added
  - Add support for Django 4.0 and 4.1.
  - Add support for Python 3.10.
  - Removed
  - Drop support for Django 3.1.
  - Drop support for Python 3.6.
- Remove upstreamed patches:
  - merged_pr_657.patch
  - pr_638.patch
* Mon Jun  6 2022 Matej Cepl <mcepl@suse.com>
- Refreshed patch pr_638.patch to the merged version.
* Sun Jun  5 2022 Matej Cepl <mcepl@suse.com>
- Updated pr_638.patch according to the latest development upstream.
* Wed May 25 2022 Markéta Machová <mmachova@suse.com>
- Do not require pytest-pythonpath for build
* Thu May 12 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v2.1.1
  * Make Django REST Framework integration always raise lower-level
    errors as ValidationError.
  * False positives in Migration changes, improvements to
    MoneyField.deconstruct.
- from v2.1
  * Add support for Django 3.2.
  * Drop support for Django 1.11, 2.1 and 3.0.
  * Drop support for Python 3.5.
- from v2.0.3
  * Inconsistent Money._copy_attributes behaviour when non-Money
    instances are involved.
- from v2.0.2
  * Inconsistent Money._copy_attributes behaviour.
- from v2.0.1
  * Invalid deprecation warning behavior.
- from v2.0
  * New setting CURRENCY_CODE_MAX_LENGTH configures default
    max_length for MoneyField and exchange app models.
  * Update py-moneyed to >=1.2,<2. It uses babel to format Money,
    which formats it differently than py-moneyed<1.
  * Money.decimal_places_display to be removed in django-money 3.0.
  * CURRENCY_DECIMAL_PLACES_DISPLAY to be removed in django-money 3.0.
- Add patches for py-moneyed v2 support
  * merged_pr_657.patch
  * pr_638.patch
* Mon May 17 2021 Markéta Machová <mmachova@suse.com>
- Update to 1.3.1
  * Django 3.1 support
  * New setting CURRENCY_DECIMAL_PLACES_DISPLAY configures decimal
    places to display for each configured currency.
* Tue Mar 31 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.0
